WELCOME_INFO = """Welcome to Elpis AI Agent.

Interactive Commands:

    In conversation, you can:

    - Ask programming questions and request code help

    - Request file reading and modification

    - Ask for terminal command execution

    - Perform project structure analysis

    - Get development guidance
    
    Type 'i' or 'index' to index code
    
    Type 'q' or 'quit' to exit the program
"""

CODEBASE_START_INDEX = 'Start indexing: '

CODEBASE_FINISH_INDEX = 'Codebase index finished! Index completed! Processing {} code blocks in total.'

NO_CODEBASE_INDEXED = "The EMBEDDING_MODEL_KEY_PREFIX environment variable is not configured to use codebase."

HUMAN_OPERATION_ALLOW_MESSAGE = "Is it allowed to operate {}? (y/n): "
